// Persistence of Vision Ray Tracer Scene Description File
// File: text.pov
// Vers: 3
// Desc: Text in a Box - exercise file for new min_extent and max_extent keywords
// Date: 12/18/97
// Auth: Ronald L. Parker

#version 3

#include "colors.inc"

global_settings
{
  assumed_gamma 1.0
}

// ----------------------------------------
camera
{
  location  <0, 1.5, -12.0>
  direction 1.5*z
  right     4/3*x
  look_at   <0.0, 0.0,  0.0>
}

sky_sphere
{
  pigment
  {
    gradient y
    color_map { [0.0 color blue 0.6] [1.0 color rgb 1] }
  }
}

light_source
{
  0*x // light's position (translated below)
  color red 1.0  green 1.0  blue 1.0  // light's color
  translate <-30, 30, -30>
}


// create a TrueType text shape
#declare newtext=text
{
  ttf          // font type (only TrueType format for now)
  "cour.ttf",  // Microsoft Windows-format TrueType font file name
  "Text In A Box",   // the string to create
  1,           // the extrusion depth
  0            // offset
  scale 3*y
  pigment {Red}
}

#declare transvect = -x * max_extent(newtext).x/2 - .5*y

#declare l=min_extent(newtext)
#declare h=max_extent(newtext)

sphere { <l.x,l.y,l.z>, .1 pigment {Yellow} translate transvect}
sphere { <l.x,l.y,h.z>, .1 pigment {Yellow} translate transvect}
sphere { <l.x,h.y,l.z>, .1 pigment {Yellow} translate transvect}
sphere { <h.x,l.y,l.z>, .1 pigment {Yellow} translate transvect}
sphere { <l.x,h.y,h.z>, .1 pigment {Yellow} translate transvect}
sphere { <h.x,h.y,l.z>, .1 pigment {Yellow} translate transvect}
sphere { <h.x,h.y,h.z>, .1 pigment {Yellow} translate transvect}

cylinder { <l.x,l.y,l.z> <l.x,l.y,h.z> .05 pigment {Green} translate transvect}
cylinder { <l.x,l.y,l.z> <l.x,h.y,l.z> .05 pigment {Green} translate transvect}
cylinder { <l.x,l.y,l.z> <h.x,l.y,l.z> .05 pigment {Green} translate transvect}
cylinder { <h.x,h.y,h.z> <l.x,h.y,h.z> .05 pigment {Green} translate transvect}
cylinder { <h.x,h.y,h.z> <h.x,l.y,h.z> .05 pigment {Green} translate transvect}
cylinder { <h.x,h.y,h.z> <h.x,h.y,l.z> .05 pigment {Green} translate transvect}
cylinder { <h.x,h.y,l.z> <h.x,l.y,l.z> .05 pigment {Green} translate transvect}
cylinder { <h.x,h.y,l.z> <l.x,h.y,l.z> .05 pigment {Green} translate transvect}
cylinder { <h.x,l.y,h.z> <h.x,l.y,l.z> .05 pigment {Green} translate transvect}
cylinder { <h.x,l.y,h.z> <l.x,l.y,h.z> .05 pigment {Green} translate transvect}
cylinder { <l.x,h.y,h.z> <l.x,l.y,h.z> .05 pigment {Green} translate transvect}
cylinder { <l.x,h.y,h.z> <l.x,h.y,l.z> .05 pigment {Green} translate transvect}

object {newtext translate transvect}
